# UTF-8 encoded Dutch language file for use with Oddmuse
#
# Copyright (c) 2003-2004 Onno Broekmans <onnod@lycos.com>
#
# Release 2 of this translation
#
# This is my first translation of OddMuse, and since I've only just
# started using OddMuse, I suspect there are still some things that
# need to be changed. Please contact me at obroekma@angelfire.com
# with any suggestions etc.
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.215.
#
$ModulesDescription .= '<p>$Id: dutch-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
U mag deze pagina niet lezen: uw account op deze Wiki, uw IP of uw netwerk is buitengesloten.
Could not create %s
Kan %s niet aanmaken
Invalid UserName %s: not saved.
Niet opgeslagen: de GebruikersNaam %s is ongeldig.
UserName must be 50 characters or less: not saved
Niet opgeslagen: de GebruikersNaam mag hoogstens 50 tekens lang zijn.
This page contains an uploaded file:

XML::RSS is not available on this system.
XML::RSS is niet beschikbaar op dit systeem.
diff
diff
history
geschiedenis
%s returned no data, or LWP::UserAgent is not available.
%s retourneerde geen data, of LWP::UserAgent is niet beschikbaar.
RSS parsing failed for %s
Lezen van RSS is niet gelukt voor %s
No items found in %s.

 . . . . 

Click to edit this page
Klik hier om deze pagina aan te maken
image

download

CGI Internal error: %s

Invalid action parameter %s
Ongeldige actieparameter %s
Invalid URL.
Ongeldige URL.
Page name is missing
Geen paginanaam opgegeven
Page name is too long: %s
De naam van de pagina is te lang :%s
Invalid Page %s
Ongeldige pagina: %s
Invalid Page %s (must not end with .db)
Ongeldige pagina; mag niet eindigen in .db: %s
Invalid Page %s (must not end with .lck)
Ongeldige pagina; mag niet eindigen in .lck: %s
Page name may not contain space characters: %s
De naam van de pagina mag geen spaties bevatten: %s
Preview:
Voorvertoning:
Preview only, not yet saved
Dit is slechts een voorvertoning; er is nog niets opgeslagen!
Please go on to %s.
Ga a.u.b. verder naar %s.
Could not open %s log file
Kan logboekbestand %s niet openen
Error was
De fout is
Note: This error is normal if no changes have been made.
NB: Deze foutmelding is gebruikelijk als er geen wijzigingen zijn gemaakt.
Could not open old %s log file
Kan oude logboekbestand %s niet openen
No updates since %s
Geen wijzigingen sinds %s
Updates since %s
Wijzigingen sinds %s
Updates in the last %s days
Wijzigingen in de laatste %s dagen
Updates in the last %s day
Wijzigingen in de laatste %s dag
for %s only
alleen voor %s
List latest change per page only
Toon alleen de laatst gewijzigde pagina's
List all changes
Toon alle wijzigingen
List only major changes
Toon alleen grote wijzigingen
Include minor changes
Toon ook kleine wijzigingen
%s days
%s dagen
List later changes
Toon latere veranderingen
Filters
Filters
Title:

Title and Body:

Username:
Gebruikersnaam:
Host:
Host:
Language:
Taal:
Go!
OK
(minor)
(klein)
rollback
ongedaan maken
new
nieuw
from %s
vanaf %s
This page is too big to send over RSS.

History of %s
Geschiedenis van %s
Compare
Vergelijk
Revision %s
Revisie %s
by
door
Rolling back changes
Bezig met ongedaan maken van wijzigingen
Missing target for rollback.
U heeft niet opegegeven tot hoever de wijzigingen ongedaan moeten worden gemaakt.
Target for rollback is too far back.
De staat waarin de pagina moet worden teruggebracht is van te lang geleden.
Rollback to %s
Wijzigingen ongedaan maken tot %s
%s rolled back
%s is in de oorspronkelijke staat teruggebracht
Index of all pages
Index van alle pagina's
Wiki Version
Tonen van Wiki-versie
Unlock Wiki
Bezig met ontgrendelen
Password
Wachtwoord
Run maintenance
Voor onderhoud uit
Unlock site
Ontgrendel site
Lock site
Vergrendel site
Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Start]
redirected from %s
doorverwezen vanaf %s
Click to search for references to this page
Klik hier om te zoeken naar verwijzingen naar deze pagina
Cookie: 
Cookie: 
Warning
Waarschuwing
Database is stored in temporary directory %s
De database is opgeslagen in de tijdelijke map %s
%s seconds
%s seconden
The same page on other sites:
Dezelfde pagina op andere sites:
EditNearLinks
WijzigNabijeKoppelingen
Last edited
Laatst gewijzigd op
Edited
Gewijzigd
by %s
door %s
(diff)
(verschillen)
Edit revision %s of this page
Wijzig revisie %s van deze pagina
Edit this page
Wijzig de tekst op deze pagina
e
e
This page is read-only
Deze pagina kan alleen gelezen worden
View other revisions
Bekijk andere revisies
View current revision
Bekijk huidige revisie
View all changes
Toon alle wijzigingen
Homepage URL:

s
s
Save
Opslaan
Preview
Voorvertoning
Search:
Zoeken naar:
f

Replace:
Vervangen door:
Validate HTML
Valideer HTML
Validate CSS
Valideer CSS
Difference (from revision %1 to %2)
Verschil (van revisie %1 naar %2)
revision %s
revisie %s
current revision
huidige revisie
Difference (from prior %s revision)
Verschil (tussen deze revisie en vorige revisie %s)
major
groot
minor
klein
No diff available.
Er is geen verschillenanalyse beschikbaar.
The two revisions are the same.

Old revision:

Changed:
Veranderd:
Removed:
Verwijderd:
Added:
Toegevoegd:
to
in
Revision %s not available
De revisie %s is niet beschikbaar
showing current revision instead
in plaats daarvan ziet u nu de huidige revisie
Showing revision %s
Dit is revisie %s
Cannot save a nameless page.
Kan een pagina zonder naam niet opslaan.
Cannot save a page without revision.

Cannot open %s
Kan %s niet openen
Cannot write %s
Kan %s niet wijzigen
Cannot create %s

Could not get %s lock
Kan %s niet vergrendelen
This operation may take several seconds...
Dit kan een aantal seconden duren...
Forced unlock of %s lock.
De vergrendeling van %s is geforceerd.
No unlock required.
Ontgrendelen is niet nodig.
%s hours ago
%s uur geleden
1 hour ago
1 uur geleden
%s minutes ago
%s minuten geleden
1 minute ago
1 minuut geleden
%s seconds ago
%s seconden geleden
1 second ago
1 seconde geleden
just now
precies op dit moment
Edit Denied
Wijzigen niet toegestaan
Editing not allowed: user, ip, or network is blocked.
U mag deze pagina niet wijzigen: uw account op deze Wiki, uw IP of uw netwerk is buitengesloten.
Contact the wiki administrator for more information.
Neem contact op met de beheerder van de wiki voor meer informatie.
The rule %s matched for you.
Uw gegevens passen bij de door de beheerder ingestelde regel %s.
See %s for more information.
Zie %s voor meer informatie.
Editing not allowed: %s is read-only.
Wijzigen niet toegestaan: %s mag alleen gelezen worden.
Only administrators can upload files.
Alleen beheerders kunnen bestanden publiceren.
Editing revision %s of
Wijzigen van revisie %s van
Editing %s
Wijzigen van %s
Editing old revision %s.
Wijzigen van oude revisie %s.
Saving this page will replace the latest revision with this text.
Als u deze pagina opslaat wordt de meest recente revisie vervangen door deze tekst.
Summary:
Samenvatting:
This change is a minor edit.
Dit is slechts een kleine wijziging.
Replace this file with text.
Vervang dit bestand door tekst.
Replace this text with a file.
Vervang deze tekst door een bestand.
File to upload: 
Te publiceren bestand: 
Files of type %s are not allowed.
Bestanden van het type %s zijn niet toegestaan.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Als uw browser gebruik maakt van cookies, is uw wachtwoord in een cookie opgeslagen. Cookies kunnen verloren gaan als u verbinding maakt vanaf een andere machine, vanaf een ander account of met behulp van andere software.
You are currently an administrator on this site.
U bent een beheerder van deze site.
You are currently an editor on this site.
U bent een redacteur op deze site.
You are a normal user on this site.
U bent een gewone gebruiker op deze site.
Your password does not match any of the  administrator or editor passwords.
Uw wachtwoord komt niet overeen met een beheerders- of redacteurswachtwoord.
Password:
Wachtwoord:
This site does not use admin or editor passwords.
Deze site heeft geen beheerders- of redacteurswachtwoorden.
This operation is restricted to site editors only...
Deze taak mag alleen uitgevoerd worden door redacteuren...
This operation is restricted to administrators only...
Deze taak mag alleen uitgevoerd worden door beheerders...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(voor %s)
Filter:

%s pages found.
%s pagina's gevonden
Replaced: %s
Vervangen door: %s
Search for: %s
Gezocht naar: %s
View changes for these pages
Toon wijzigingen in deze pagina's
Search sites on the %s as well
Zoek ook sites op de %s
and
en
or
of
Fetching results from %s:
Bezig met ophalen resultaten van %s:
Near pages:
Nabije pagina's:
last updated
laatst gewijzigd
Complete Content
Volledige inhoud
The main page is %s.
De hoofdpagina is %s.
Comments on this page
Commentaar op deze pagina
Editing not allowed for %s.
Het wijzigen van %s is niet toegestaan.
SampleUndefinedPage
VoorbeeldVanEenNietBestaandePagina
%s cannot be defined.
%s kan niet aangemaakt worden.
Sample_Undefined_Page
Voorbeeld_Van_Een_Niet_Bestaande_Pagina
[[%s]] cannot be defined.
[[%s]] kan niet aangemaakt worden.
Only an administrator can create %s.
Alleen een beheerder kan %s aanmaken.
Transfer Error: %s
Fout tijdens overdacht: %s
Browser reports no file info.
Uw browser heeft geen informatie over het bestand opgegeven.
Browser reports no file type.
Uw browser heeft geen informatie over het bestandstype opgegeven.
The page contains banned text.
Deze pagina bevat verbannen tekst.
No changes to be saved.

This page was changed by somebody else %s.
Deze pagina is gewijzigd door iemand anders %s.
The changes conflict.  Please check the page again.
De wijzigingen zijn strijdig met elkaar. Controleer de pagina a.u.b. opnieuw.
Please check whether you overwrote those changes.
Controleer a.u.b. of u die wijzigingen overschreven heeft.
Anonymous
Anoniem
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
Kan de pagina niet vergrendelen voor het samenvoegen
you
u
ancestor
vorige revisie
other
ander
Run Maintenance

Maintenance not done.
Er is geen onderhoud gepleegd.
(Maintenance can only be done once every 12 hours.)
(Onderhoud kan slechts eens in de 12 uur uitgevoerd worden.)
Remove the "maintain" file or wait.
Verwijder het bestand "maintain" of wacht.
Main lock obtained.
De gehele site is vergrendeld.
Expiring keep files and deleting pages marked for deletion
Bezig met verwijderen van te oude revisies uit de archieven, en verwijderen van pagina's die daarvoor gemarkeerd zijn
not deleted: 
niet verwijderd: 
deleted
verwijderd
Moving part of the %s log file.
Bezig met verplaatsen van een deel van het logboekbestand %s
Moving %s log entries.
Bezig met verplaatsen van %s items.
Getting page index file for %s.
Bezig met ophalen indexbestand voor %s.
Main lock released.
De vergrendeling van de gehele site is opgeheven.
Set or Remove global edit lock
Ver-/ontgrendelen van de gehele site
Edit lock created.
De gehele site is vergrendeld; er an nu niets meer gewijzigd worden.
Edit lock removed.
De site is ontgrendeld; er kunnen nu weer wijzigingen aangebracht worden.
Set or Remove page edit lock
Ver-/ontgrendelen van pagina
Missing page id to lock/unlock...
U heeft niet opgegeven welke pagina ver-/ontgrendeld moet worden.
Lock for %s created.
%s is vergrendeld, en kan nu niet meer gewijzigd worden.
Lock for %s removed.
%s is ontgrendeld, en kan nu weer gewijzigd worden.
Displaying Wiki Version

Show dependencies

Inter links:
Interkoppelingen:
Near links:
Nabije koppelingen:
Show parsed link data

Too many connections by %s
Te veel verbindingen met %s
Please do not fetch more than %1 pages in %2 seconds.
Haal a.u.b. niet meer dan %s pagina's op in %2 seconden.
Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s
bladwijzer als eerste hier gedefinieerd: %s
Click to search for references to this permanent anchor
Klik hier om te zoeken naar verwijzingen naar deze permanente bladwijzer
the page %s also exists
de pagina %s bestaat ook
Copy one of the following stylesheets to %s:

Deleting %s
Bezig met verwijderen van %s
Deleted %s
%s is verwijderd
Renaming %1 to %2.
Bezig met hernoemen van %1 in %2.
The page %s does not exist
De pagina %s bestaat niet
The page %s already exists
De pagina %s bestaat al
Cannot rename %1 to %2

Renamed to %s
Hernoemd in %s
Renamed from %s
Hernoemd van %s
Renamed %1 to %2.
%1 hernoemd in %2.
Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Recent Visitors
Recente bezoekers
some action

was here

and read

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
The match parameter is missing.
De parameter 'match' ontbreekt.
Page Collection for %s
Paginaverzameling voor %s
Previous

Next

Calendar %s
Kalender %s
Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:
Voetnoten:
Could not find %1.html template in %2

Only Editors are allowed to see hidden pages.

Only Admins are allowed to see hidden pages.

image: %s
afbeelding: %s
Index

Languages:
Talen:
Show!
Tonen!
Define
Definiëren
Full Link List
Volledige lijst van koppelingen
Template without parameters

The template %s is either empty or does not exist.

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

  Please allow time for the webmaster to approve your request.

  An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

<p>Logout of %s?</p>

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s

The username "%s" does not exist.

Reset Password for %s

<p>Reset Password?</p>

Change Password for %s

<p>Change Password?</p>

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Clearing Cache
Bezig met leegmaken van de cache
Done.

Generating Link Database
Bezig met genereren van Koppelingendatabase
The 404 handler extension requires the link data extension (links.pl).
The 404 handler extension requires the link data extension (links.pl).
LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List
Lijst met Wezen
Trail: 
Spoor: 
None
Geen
Type
Type
Permalink to "%s"

Portrait
Portret
You did not answer correctly.

All Referrers
Alle verwijzingen
Referrers
Verwijzingen
Rebuild index for searching

Rebuilding Index

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s
Terug naar %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Tag

Alternatively, use one of the following templates:

Thread: %s
Draad: %s
ID parameter is missing.
Parameter 'ID' ontbreekt.
Thread %s does not exist.
De draad %s bestaat niet.
Page %s does not contain a thread.
De pagina %s bevat geen draad.
Add
Voeg toe
URL parameter is missing.
Parameter 'URL' ontbreekt.
Add to %s thread
Voeg toe aan de draad %s
Below:
Onder:
URL:
URL:
Name:
Naam:
Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.com/exec/obidos/ISBN=%s
alternate
alternatief
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
search
zoeken
Upload of %s file

Blog
Blog
Matching pages:

New

Edit %s.

END_OF_TRANSLATION
